@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -336,7 +336,7 @@ class BtoeClient(AbstractClient):
 
 
     def VerifyEvidenceBlockChainTxHash(self, request):
-        """用户向BTOE核验存证结果中的区块链交易hash
+        """用户向BTOE核验存证结果中的区块链交易hash的真实性
 
         :param request: Request instance for VerifyEvidenceBlockChainTxHash.
         :type request: :class:`tencentcloud.btoe.v20210514.models.VerifyEvidenceBlockChainTxHashRequest`
